@@ -26,11 +26,6 @@ class HttpMethodOverrideMiddleware:
             if 'csrfmiddlewaretoken' in request.POST:
                 request.META.setdefault('HTTP_X_CSRFTOKEN', request.POST['csrfmiddlewaretoken'])
 
-            # In the interest of keeping the request pristine, we discard the "_method" key
-            # and set its "POST" attribute to an empty QueryDict.
-            if '_method' in request.POST:
-                request._raw_post_data = re.sub(r'_method=(PUT|PATCH|DELETE)&?', '', request.raw_post_data)
-
             request.POST = QueryDict('')
 
 class HttpPutMiddleware:
